==> savane-1.0.2.tar.gz: savane/frontend/php/people/createjob.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: createjob.php,v 1.17 2004/03/13 18:22:06 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#                          Mathieu Roy <yeupou--at--gnu.org>
#
#  Copyright 2004      (c) ...
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";

if ($group_id && (user_ismember($group_id, 'A'))) {

  /*
		Fill in the info to create a job
  */

  site_project_header(array('title'=>_("Create a job for your project"),'group'=>$group_id,'toptab'=>'ahome'));

  # we get site-specific content
  utils_get_content("people/createjob");

  echo '
		<form action="'.$GLOBALS['sys_home'].'people/editjob.php" method="POST">
		<input type="HIDDEN" name="group_id" value="'.$group_id.'">
		<b>'
    ._("Category:").'</b><br>'
    . people_job_category_box('category_id') .'
		<p>
		<b>'
    ._("Summary").':</b><br>
		<input type="text" name="title" value="" size="40" maxlength="60">
		<p>'
    ._("Your project description will be inserted on the announce.").'
        <p>
		<b>'
    ._("Details (job description, contact...):").'</b><br>
		<textarea name="description" rows="10" cols="60" wrap="soft"></textarea>
		<p>
		<input type="submit" name="add_job" value="'
    ._("continue >>").'">
		</form>';

  site_project_footer(array());

} else {
  /*
		Not logged in or insufficient privileges
  */
  if (!$group_id) {
    exit_no_group();
  } else {
    exit_permission_denied();
  }
}
?>

==> savane-1.0.3.1.tar.gz: savane/frontend/php/people/createjob.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: createjob.php,v 1.18 2004/06/26 08:02:16 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#                          Mathieu Roy <yeupou--at--gnu.org>
#
#  Copyright 2004      (c) ...
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";

if ($_POST['group_id'])
   { 
   $group_id = $_POST['group_id']; 
   }
elseif ($_GET['group_id'])
   { 
   $group_id = $_GET['group_id']; 
   }
   
if ($group_id && (user_ismember($group_id, 'A'))) {

  /*
		Fill in the info to create a job
  */

  site_project_header(array('title'=>_("Create a job for your project"),'group'=>$group_id,'toptab'=>'ahome'));

  # we get site-specific content
  utils_get_content("people/createjob");

  echo '
		<form action="'.$GLOBALS['sys_home'].'people/editjob.php" method="POST">
		<input type="HIDDEN" name="group_id" value="'.$group_id.'">
		<b>'
    ._("Category:").'</b><br>'
    . people_job_category_box('category_id') .'
		<p>
		<b>'
    ._("Summary").':</b><br>
		<input type="text" name="title" value="" size="40" maxlength="60">
		<p>'
    ._("Your project description will be inserted on the announce.").'
        <p>
		<b>'
    ._("Details (job description, contact...):").'</b><br>
		<textarea name="description" rows="10" cols="60" wrap="soft"></textarea>
		<p>
		<input type="submit" name="add_job" value="'
    ._("continue >>").'">
		</form>';

  site_project_footer(array());

} else {
  /*
		Not logged in or insufficient privileges
  */
  if (!$group_id) {
    exit_no_group();
  } else {
    exit_permission_denied();
  }
}
?>
